summaryrefslogtreecommitdiff
path: root/vcl/generic/glyphs/gcach_ftyp.hxx
diff options
context:
space:
mode:
authorChris Sherlock <chris.sherlock79@gmail.com>2016-01-07 15:25:31 +1100
committerChris Sherlock <chris.sherlock79@gmail.com>2016-01-07 15:26:58 +1100
commitf5151af414f0ac0590d87040929cabe7f8db3106 (patch)
tree906a6927740aef3d9c63e54a3606bce07b4c737f /vcl/generic/glyphs/gcach_ftyp.hxx
parent575d39c56feb2102ad3c68da960f6630c12baefa (diff)
vcl: FtFont{Info|File} renamed to FreetypeFont{Info|Type}
Change-Id: I91621a177f27200c9d3413dd4953d5292a2ac15b
Diffstat (limited to 'vcl/generic/glyphs/gcach_ftyp.hxx')
-rw-r--r--vcl/generic/glyphs/gcach_ftyp.hxx30
1 files changed, 15 insertions, 15 deletions
diff --git a/vcl/generic/glyphs/gcach_ftyp.hxx b/vcl/generic/glyphs/gcach_ftyp.hxx
index 32777770db03..acd74ec36263 100644
--- a/vcl/generic/glyphs/gcach_ftyp.hxx
+++ b/vcl/generic/glyphs/gcach_ftyp.hxx
@@ -28,13 +28,13 @@
class GraphiteFaceWrapper;
#endif
// FtFontFile has the responsibility that a font file is only mapped once.
// (#86621#) the old directly ft-managed solution caused it to be mapped
// in up to nTTC*nSizes*nOrientation*nSynthetic times
-class FtFontFile
+class FreetypeFontFile
{
public:
- static FtFontFile* FindFontFile( const OString& rNativeFileName );
+ static FreetypeFontFile* FindFontFile( const OString& rNativeFileName );
bool Map();
void Unmap();
@@ -45,7 +45,7 @@ public:
int GetLangBoost() const { return mnLangBoost; }
private:
- explicit FtFontFile( const OString& rNativeFileName );
+ explicit FreetypeFontFile( const OString& rNativeFileName );
const OString maNativeFileName;
unsigned char* mpFileMap;
@@ -54,14 +54,14 @@ private:
int mnLangBoost;
};
-// FtFontInfo corresponds to an unscaled font face
-class FtFontInfo
+// FreetypeFontInfo corresponds to an unscaled font face
+class FreetypeFontInfo
{
public:
- FtFontInfo( const ImplFontAttributes&,
+ FreetypeFontInfo( const ImplFontAttributes&,
const OString& rNativeFileName,
int nFaceNum, sal_IntPtr nFontId);
- ~FtFontInfo();
+ ~FreetypeFontInfo();
const unsigned char* GetTable( const char*, sal_uLong* pLength=nullptr ) const;
@@ -86,7 +86,7 @@ public:
private:
FT_FaceRec_* maFaceFT;
- FtFontFile* mpFontFile;
+ FreetypeFontFile* mpFontFile;
const int mnFaceNum;
int mnRefCount;
#if ENABLE_GRAPHITE
@@ -108,7 +108,7 @@ private:
// these two inlines are very important for performance
-inline int FtFontInfo::GetGlyphIndex( sal_UCS4 cChar ) const
+inline int FreetypeFontInfo::GetGlyphIndex( sal_UCS4 cChar ) const
{
if( !mpChar2Glyph )
return -1;
@@ -118,7 +118,7 @@ inline int FtFontInfo::GetGlyphIndex( sal_UCS4 cChar ) const
return it->second;
}
-inline void FtFontInfo::CacheGlyphIndex( sal_UCS4 cChar, int nIndex ) const
+inline void FreetypeFontInfo::CacheGlyphIndex( sal_UCS4 cChar, int nIndex ) const
{
if( !mpChar2Glyph )
InitHashes();
@@ -140,7 +140,7 @@ public:
ServerFont* CreateFont( const FontSelectPattern& );
private:
- typedef std::unordered_map<sal_IntPtr,FtFontInfo*> FontList;
+ typedef std::unordered_map<sal_IntPtr,FreetypeFontInfo*> FontList;
FontList maFontList;
sal_IntPtr mnMaxFontId;
@@ -149,14 +149,14 @@ private:
class ImplFTSFontData : public PhysicalFontFace
{
private:
- FtFontInfo* mpFtFontInfo;
+ FreetypeFontInfo* mpFreetypeFontInfo;
public:
- ImplFTSFontData( FtFontInfo*, const ImplFontAttributes& );
+ ImplFTSFontData( FreetypeFontInfo*, const ImplFontAttributes& );
virtual ImplFontEntry* CreateFontInstance( FontSelectPattern& ) const override;
virtual PhysicalFontFace* Clone() const override { return new ImplFTSFontData( *this ); }
- virtual sal_IntPtr GetFontId() const override { return mpFtFontInfo->GetFontId(); }
+ virtual sal_IntPtr GetFontId() const override { return mpFreetypeFontInfo->GetFontId(); }
};
#endif // INCLUDED_VCL_GENERIC_GLYPHS_GCACH_FTYP_HXX
@@ -28,13 +28,13 @@
class GraphiteFaceWrapper;
#endif
-// FtFontFile has the responsibility that a font file is only mapped once.
+// FreetypeFontFile has the responsibility that a font file is only mapped once.
// (#86621#) the old directly ft-managed solution caused it to be mapped
// in up to nTTC*nSizes*nOrientation*nSynthetic times